==> haskell-warp-tls-3.4.9-147-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-DUn5gdyyIzToYDi6W43eW
key:                  warp-tls-3.4.9-DUn5gdyyIzToYDi6W43eW
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  8259fed7c4a95853f8e671d05d7a1bcf
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-DUn5gdyyIzToYDi6W43eW
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    recv-0.1.1-KL1l6q82N9lBbU90bqLNR8
    streaming-commons-0.2.3.0-msDAcRqGslCe0T6zzs6il
    tls-2.0.6-IakNTBA0JiNDRPputM9FQX
    tls-session-manager-0.0.5-g89xTYIbseE5XkpCf4Jsh
    unliftio-0.2.25.1-83PwQVOhURl3H5nxoMcX3o
    wai-3.2.4-LnpkwzoHUW9G2cGUC0nKUm warp-3.3.30-BXGJjdXXESkBepSPGuenDW

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.4.9-175-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-4ZV7VdRn5rE7CjkZQzMmkr
key:                  warp-tls-3.4.9-4ZV7VdRn5rE7CjkZQzMmkr
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  b98f9fc30d913eab9fb85be6f92532d3
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-4ZV7VdRn5rE7CjkZQzMmkr
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    recv-0.1.1-Al3W4kRSV8IEvMYmDR1eCZ
    streaming-commons-0.2.3.0-7nYylEY3bibBf5EXMr0TCn
    tls-2.0.6-I1Ld4heBgrMIPyOIwAkQZM
    tls-session-manager-0.0.6-9OlaKYprwuXINxXeNpcAjp
    unliftio-0.2.25.1-jUDvU4O8PS8SoQvWmG5yt
    wai-3.2.4-GKgviHtnWhO3KoBTtmAmpl warp-3.4.0-4WQzRXYOsvYHbiPfjmDm2s

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
